=== modified file 'bzrlib/conflicts.py'
--- bzrlib/conflicts.py	2005-12-01 23:52:16 +0000
+++ bzrlib/conflicts.py	2006-02-28 15:14:52 +0000
@@ -26,10 +26,9 @@
 import errno
 
 import bzrlib.status
-from bzrlib.branch import Branch
 from bzrlib.errors import BzrCommandError, NotConflicted
 from bzrlib.commands import register_command
-from bzrlib.workingtree import CONFLICT_SUFFIXES
+from bzrlib.workingtree import CONFLICT_SUFFIXES, WorkingTree
 from bzrlib.osutils import rename
 
 class cmd_conflicts(bzrlib.commands.Command):
@@ -38,7 +37,7 @@
     files.)
     """
     def run(self):
-        for path in Branch.open_containing(u'.')[0].working_tree().iter_conflicts():
+        for path in WorkingTree.open_containing(u'.')[0].iter_conflicts():
             print path
 
 class cmd_resolve(bzrlib.commands.Command):
@@ -52,7 +51,7 @@
             if not all:
                 raise BzrCommandError(
                     "command 'resolve' needs one or more FILE, or --all")
-            tree = Branch.open_containing(u'.')[0].working_tree()
+            tree = WorkingTree.open_containing(u'.')[0]
             file_list = list(tree.abspath(f) for f in tree.iter_conflicts())
         else:
             if all:

=== modified file 'bzrlib/tests/blackbox/__init__.py'
--- bzrlib/tests/blackbox/__init__.py	2006-02-23 15:47:19 +0000
+++ bzrlib/tests/blackbox/__init__.py	2006-02-28 15:14:52 +0000
@@ -38,6 +38,7 @@
                      'bzrlib.tests.blackbox.test_cat',
                      'bzrlib.tests.blackbox.test_checkout',
                      'bzrlib.tests.blackbox.test_commit',
+                     'bzrlib.tests.blackbox.test_conflicts',
                      'bzrlib.tests.blackbox.test_diff',
                      'bzrlib.tests.blackbox.test_export',
                      'bzrlib.tests.blackbox.test_find_merge_base',

=== added file 'bzrlib/tests/blackbox/test_conflicts.py'
--- bzrlib/tests/blackbox/test_conflicts.py	1970-01-01 00:00:00 +0000
+++ bzrlib/tests/blackbox/test_conflicts.py	2006-02-28 15:14:52 +0000
@@ -0,0 +1,64 @@
+# Copyright (C) 2006 by Canonical Ltd
+# -*- coding: utf-8 -*-
+
+# This program is free software; you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 2 of the License, or
+# (at your option) any later version.
+
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+
+# You should have received a copy of the GNU General Public License
+# along with this program; if not, write to the Free Software
+# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+
+import os
+
+from bzrlib.tests.blackbox import ExternalBase
+
+class TestConflicts(ExternalBase):
+    def setUp(self):
+        super(ExternalBase, self).setUp()
+        try:
+            os.mkdir('a')
+        except:
+            raise os.getcwd()
+        os.chdir('a')
+        self.runbzr('init')
+        file('myfile', 'wb').write('contentsa\n')
+        file('my_other_file', 'wb').write('contentsa\n')
+        self.runbzr('add')
+        self.runbzr('commit -m new')
+        os.chdir('..')
+        self.runbzr('branch a b')
+        os.chdir('b')
+        file('myfile', 'wb').write('contentsb\n')
+        file('my_other_file', 'wb').write('contentsb\n')
+        self.runbzr('commit -m change')
+        os.chdir('../a')
+        file('myfile', 'wb').write('contentsa2\n')
+        file('my_other_file', 'wb').write('contentsa2\n')
+        self.runbzr('commit -m change')
+        self.runbzr('merge ../b', retcode=1)
+
+    def test_conflicts(self):
+        conflicts = self.runbzr('conflicts', backtick=True)
+        self.assertEqual(len(conflicts.splitlines()), 2)
+
+    def test_resolve(self):
+        self.runbzr('resolve', retcode=3)
+        self.runbzr('resolve myfile')
+        conflicts = self.runbzr('conflicts', backtick=True)
+        self.assertEqual(len(conflicts.splitlines()), 1)
+        self.runbzr('resolve my_other_file')
+        conflicts = self.runbzr('conflicts', backtick=True)
+        self.assertEqual(len(conflicts.splitlines()), 0)
+
+    def test_resolve_all(self):
+        self.runbzr('resolve --all')
+        conflicts = self.runbzr('conflicts', backtick=True)
+        self.assertEqual(len(conflicts.splitlines()), 0)
+

